@@ -1,4 +1,5 @@
 # encoding: utf-8
+from __future__ import unicode_literals
 import datetime
 from south.db import db
 from south.v2 import DataMigration
@@ -8,7 +9,12 @@ class Migration(DataMigration):
 
     def forwards(self, orm):
         from django.contrib.sites.models import Site
-        orm.Setting.objects.all().update(site=Site.objects.get_current())
+        try:
+            site = Site.objects.get_current()
+        except Site.DoesNotExist:
+            pass
+        else:
+            orm.Setting.objects.all().update(site=site)
 
 
     def backwards(self, orm):
