@@ -1,5 +1,11 @@
+from __future__ import absolute_import, unicode_literals
+from future.builtins import int, open
+
 import os
-from urlparse import urljoin, urlparse
+try:
+    from urllib.parse import urljoin, urlparse
+except ImportError:
+    from urlparse import urljoin, urlparse
 
 from django.contrib import admin
 from django.contrib.admin.views.decorators import staff_member_required
@@ -92,8 +98,8 @@ def edit(request):
         model_admin.log_change(request, obj, message)
         response = ""
     else:
-        response = form.errors.values()[0][0]
-    return HttpResponse(unicode(response))
+        response = list(form.errors.values())[0][0]
+    return HttpResponse(response)
 
 
 def search(request, template="search_results.html"):
@@ -165,6 +171,33 @@ def static_proxy(request):
     return HttpResponse(response, mimetype=mimetype)
 
 
+def displayable_links_js(request, template_name="admin/displayable_links.js"):
+    """
+    Renders a list of url/title pairs for all ``Displayable`` subclass
+    instances into JavaScript that's used to populate a list of links
+    in TinyMCE.
+    """
+    links = []
+    if "mezzanine.pages" in settings.INSTALLED_APPS:
+        from mezzanine.pages.models import Page
+        is_page = lambda obj: isinstance(obj, Page)
+    else:
+        is_page = lambda obj: False
+    # For each item's title, we use its model's verbose_name, but in the
+    # case of Page subclasses, we just use "Page", and then sort the items
+    # by whether they're a Page subclass or not, then by their URL.
+    for url, obj in Displayable.objects.url_map(for_user=request.user).items():
+        title = getattr(obj, "titles", obj.title)
+        real = hasattr(obj, "id")
+        page = is_page(obj)
+        if real:
+            verbose_name = _("Page") if page else obj._meta.verbose_name
+            title = "%s: %s" % (verbose_name, title)
+        links.append((not page and real, url, title))
+    context = {"links": [link[1:] for link in sorted(links)]}
+    return render(request, template_name, context, mimetype="text/javascript")
+
+
 @requires_csrf_token
 def page_not_found(request, template_name="errors/404.html"):
     """
