@@ -4,6 +4,9 @@ all the various Mezzanine apps, third-party apps like Grappelli and
 filebrowser.
 """
 
+from __future__ import unicode_literals
+from future.builtins import str
+
 from django.conf.urls import patterns, include
 from django.contrib import admin
 from django.contrib.admin.sites import NotRegistered
@@ -18,7 +21,7 @@ from mezzanine.core.sitemaps import DisplayableSitemap
 for model in settings.ADMIN_REMOVAL:
     try:
         model = tuple(model.rsplit(".", 1))
-        exec "from %s import %s" % model
+        exec("from %s import %s" % model)
     except ImportError:
         pass
     else:
@@ -31,10 +34,7 @@ for model in settings.ADMIN_REMOVAL:
 urlpatterns = []
 
 # JavaScript localization feature
-js_info_dict = {
-    'domain': 'django',
-}
-
+js_info_dict = {'domain': 'django'}
 urlpatterns += patterns('django.views.i18n',
     (r'^jsi18n/(?P<packages>\S+?)/$', 'javascript_catalog', js_info_dict),
 )
@@ -99,7 +99,7 @@ if "mezzanine.pages" in settings.INSTALLED_APPS:
         PAGES_SLUG = getattr(settings, "PAGES_SLUG", "pages").strip("/") + "/"
         blog_patterns_start = urlpatterns.index(blog_patterns[0])
         urlpatterns[blog_patterns_start:len(blog_patterns)] = patterns("",
-            ("^%s" % unicode(PAGES_SLUG), include("mezzanine.pages.urls")),
+            ("^%s" % str(PAGES_SLUG), include("mezzanine.pages.urls")),
         )
     else:
         urlpatterns += patterns("",
