@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 
 import os
 import sys
@@ -61,14 +62,15 @@ def set_dynamic_settings(s):
     # Change tuple settings to lists for easier manipulation.
     s.setdefault("AUTHENTICATION_BACKENDS", defaults.AUTHENTICATION_BACKENDS)
     s.setdefault("STATICFILES_FINDERS", defaults.STATICFILES_FINDERS)
-    tuple_list_settings = ("AUTHENTICATION_BACKENDS", "INSTALLED_APPS",
-                           "MIDDLEWARE_CLASSES", "STATICFILES_FINDERS")
-    for setting in tuple_list_settings:
-        s[setting] = list(s[setting])
-
-    if s["DEV_SERVER"]:
-        s["STATICFILES_DIRS"] = list(s.get("STATICFILES_DIRS", []))
-        s["STATICFILES_DIRS"].append(s.pop("STATIC_ROOT"))
+    tuple_list_settings = ["AUTHENTICATION_BACKENDS", "INSTALLED_APPS",
+                           "MIDDLEWARE_CLASSES", "STATICFILES_FINDERS"]
+    for i, setting in enumerate(tuple_list_settings[:]):
+        if not isinstance(s[setting], list):
+            s[setting] = list(s[setting])
+        else:
+            # Setting is already a list, so we'll exclude it from
+            # the list of settings we'll revert back to tuples.
+            del tuple_list_settings[i]
 
     # Set up cookie messaging if none defined.
     storage = "django.contrib.messages.storage.cookie.CookieStorage"
@@ -105,7 +107,7 @@ def set_dynamic_settings(s):
                     s["INSTALLED_APPS"].append(app)
     if "debug_toolbar" in s["INSTALLED_APPS"]:
         debug_mw = "debug_toolbar.middleware.DebugToolbarMiddleware"
-        prepend("MIDDLEWARE_CLASSES", debug_mw)
+        append("MIDDLEWARE_CLASSES", debug_mw)
     # If compressor installed, ensure it's configured and make
     # Mezzanine's settings available to its offline context,
     # since jQuery is configured via a setting.
@@ -144,6 +146,9 @@ def set_dynamic_settings(s):
     # are loaded in the correct order.
     move("INSTALLED_APPS", "django.contrib.admin", len(s["INSTALLED_APPS"]))
 
+    # Ensure we have a test runner (removed in Django 1.6)
+    s.setdefault("TEST_RUNNER", "django.test.simple.DjangoTestSuiteRunner")
+
     # Add missing apps if existing apps depend on them.
     if "mezzanine.blog" in s["INSTALLED_APPS"]:
         append("INSTALLED_APPS", "mezzanine.generic")
